(* Copyright 2003 Alan Post
 *
 * This file is part of mineml.
 *
 * mineml is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * mineml is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with mineml; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)

type t
type cell_state_t = Marked | Hidden | Open

exception Cant_hide_open
exception Cant_mark_open
exception Cant_open_marked
exception Dead of int * int
exception Won

val make          : width:int -> height:int -> n_mines:int ->
                    autoclear:bool -> t

val width         : t -> int
val height        : t -> int
val state         : t -> (int * int) -> cell_state_t
val clear_around  : t -> (int * int) -> unit
val set_state     : t -> (int * int) -> cell_state_t -> unit
val n_surround    : t -> (int * int) -> int
val is_mine       : t -> (int * int) -> bool
val set_autoclear : t -> bool -> unit
val total_marked  : t -> int
val total_mines   : t -> int

val clear_dirties : t -> unit
val dirty_list    : t -> (int * int) list

val as_string     : t -> string
