(* Code copyright 2003 Alan Post
 *
 * This file is part of mineml.
 *
 * mineml is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * mineml is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with mineml; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *************************************************
 *
 * Images copyright 1993-1999 Marc Baudoin,
 *   available in the 'xdemineur' program under the following license:
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.  The author makes no representations about the suitability of
 * this software for any purpose.  It is provided "as is" without express or
 * implied warranty.
 *)

type img_state_t = 
    ImgHidden | ImgOpen | ImgMarked | ImgMine | ImgBlam | ImgWrong

let hidden_pixmap = ref None
let marked_pixmap = ref None
let mine_pixmap = ref None
let blam_pixmap = ref None
let wrong_pixmap = ref None
let open_pixmap_arr = ref [||]

let init window =
    hidden_pixmap := Some (GDraw.pixmap_from_xpm_d ~window ~data: [|
"20 20 4 1";
"  c white";
"X c gray50 m black";
"* c gray70 m black";
". c gray70 m white";
"                    ";
"                   X";
"                  XX";
"   *.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*XXX";
"   XXXXXXXXXXXXXXXXX";
"  XXXXXXXXXXXXXXXXXX";
" XXXXXXXXXXXXXXXXXXX";
|] ());

    marked_pixmap := Some (GDraw.pixmap_from_xpm_d ~window ~data: [|
"20 20 6 1";
"  c white";
"# c black";
"X c gray50 m black";
"* c gray70 m black";
". c gray70 m white";
"- c red    m black";
"                    ";
"                   X";
"                  XX";
"   *.*.*.*.*.*.*.XXX";
"   .*.*.*--.*.*.*XXX";
"   *.*.----*.*.*.XXX";
"   .*------.*.*.*XXX";
"   *-------*.*.*.XXX";
"   .*------.*.*.*XXX";
"   *.*.----*.*.*.XXX";
"   .*.*.*--.*.*.*XXX";
"   *.*.*.*#*.*.*.XXX";
"   .*.*.*.#.*.*.*XXX";
"   *.*.*####.*.*.XXX";
"   .*.########*.*XXX";
"   *.##########*.XXX";
"   .*.*.*.*.*.*.*XXX";
"   XXXXXXXXXXXXXXXXX";
"  XXXXXXXXXXXXXXXXXX";
" XXXXXXXXXXXXXXXXXXX";
|] ());

    mine_pixmap := Some (GDraw.pixmap_from_xpm_d ~window ~data: [|
"20 20 3 1";
"  c white";
"# c black";
". c gray70 m white";
"....................";
".........##.........";
".........##.........";
"...#....####....#...";
"....#.########.#....";
".....##########.....";
"....############....";
"....###   ######....";
"...####   #######...";
".######   #########.";
".##################.";
"...##############...";
"....############....";
"....############....";
".....##########.....";
"....#.########.#....";
"...#....####....#...";
".........##.........";
".........##.........";
"....................";
|] ());

    blam_pixmap := Some (GDraw.pixmap_from_xpm_d ~window ~data: [|
"20 20 3 1";
"  c white m black";
"# c black m white";
". c red   m black";
"....................";
".........##.........";
".........##.........";
"...#....####....#...";
"....#.########.#....";
".....##########.....";
"....############....";
"....###   ######....";
"...####   #######...";
".######   #########.";
".##################.";
"...##############...";
"....############....";
"....############....";
".....##########.....";
"....#.########.#....";
"...#....####....#...";
".........##.........";
".........##.........";
"....................";
|] ());

    wrong_pixmap := Some (GDraw.pixmap_from_xpm_d ~window ~data: [|
"20 20 5 1";
"  c white";
"# c black";
"* c black  m white";
". c gray70 m white";
"- c red    m black";
"....................";
".--......#*......--.";
".---.....*#.....---.";
"..---...*#*#...---..";
"...---#*#*#*#*---...";
"....---#*#*#*---....";
"....#---#*#*---*....";
"....*#--- *---*#....";
"...*#*#------*#*#...";
".#*#*#* ----*#*#*#*.";
".*#*#*#*----#*#*#*#.";
"...#*#*------#*#*...";
"....#*---*#---#*....";
"....*---*#*#---#....";
"....---*#*#*#---....";
"...---*#*#*#*#---...";
"..---...#*#*...---..";
".---.....#*.....---.";
".--......*#......--.";
"....................";
|] ());

    open_pixmap_arr := Array.map
        (fun data -> GDraw.pixmap_from_xpm_d ~window ~data ())
[|
[|
"20 20 1 1";
". c gray70 m white";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
"....................";
|];

[|
"20 20 2 1";
". c gray70 m white";
"- c blue   m black";
"....................";
"....................";
"..........--........";
".........---........";
"........----........";
".......-----........";
"......------........";
".....-------........";
"........----........";
"........----........";
"........----........";
"........----........";
"........----........";
"........----........";
"........----........";
".....----------.....";
".....----------.....";
".....----------.....";
"....................";
"....................";
|];

[|
"20 20 2 1";
". c gray70      m white";
"- c forestgreen m black";
"....................";
"....................";
"......--------......";
".....----------.....";
"....------------....";
"....---......---....";
"....---.....----....";
"...........----.....";
"..........----......";
".........----.......";
"........----........";
".......----.........";
"......----..........";
".....----...........";
"....----............";
"....------------....";
"....------------....";
"....------------....";
"....................";
"....................";
|];

[|
"20 20 2 1";
". c gray70 m white";
"- c red    m black";
"....................";
"....................";
"....----------......";
"....-----------.....";
"....------------....";
"............----....";
"............----....";
"............----....";
"........-------.....";
"........------......";
"........-------.....";
"............----....";
"............----....";
"............----....";
"....------------....";
"....-----------.....";
"....----------......";
"....................";
"....................";
"....................";
|];

[|
"20 20 2 1";
". c gray70 m white";
"- c navy   m black";
"....................";
"....................";
".......---.----.....";
"......----.----.....";
"......----.----.....";
".....----..----.....";
".....----..----.....";
"....----...----.....";
"....----...----.....";
"....------------....";
"....------------....";
"....------------....";
"...........----.....";
"...........----.....";
"...........----.....";
"...........----.....";
"...........----.....";
"...........----.....";
"....................";
"....................";
|];

[|
"20 20 2 1";
". c gray70 m white";
"- c orchid m black";
"....................";
"....................";
"....------------....";
"....------------....";
"....------------....";
"....---.............";
"....---.............";
"....---.............";
"....----------......";
"....-----------.....";
"....------------....";
".............---....";
".............---....";
"....---......---....";
"....------------....";
".....----------.....";
"......--------......";
"....................";
"....................";
"....................";
|];

[|
"20 20 2 1";
". c gray70   m white";
"- c seagreen m black";
"....................";
"....................";
"......----------....";
".....-----------....";
"....------------....";
"....---.............";
"....---.............";
"....---.............";
"....----------......";
"....-----------.....";
"....------------....";
"....---......---....";
"....---......---....";
"....---......---....";
"....------------....";
".....----------.....";
"......--------......";
"....................";
"....................";
"....................";
|];

[|
"20 20 2 1";
". c gray70 m white";
"- c sienna m white";
"....................";
"....................";
"....------------....";
"....------------....";
"....------------....";
"............---.....";
"............---.....";
"...........---......";
"...........---......";
"..........---.......";
"..........---.......";
".........---........";
".........---........";
"........---.........";
"........---.........";
".......---..........";
".......---..........";
".......---..........";
"....................";
"....................";
|];

[|
"20 20 2 1";
". c gray70   m white";
"- c deeppink m white";
"....................";
"....................";
"......--------......";
".....----------.....";
"....------------....";
"....-----..-----....";
"....----....----....";
"....-----..-----....";
".....----------.....";
"......--------......";
".....----------.....";
"....-----..-----....";
"....----....----....";
"....-----..-----....";
"....------------....";
".....----------.....";
"......--------......";
"....................";
"....................";
"....................";
|]
|]

let extract o = match o with None -> raise Exit | Some x -> x
let get st surround = match st with
    ImgHidden -> extract !hidden_pixmap
  | ImgMarked -> extract !marked_pixmap
  | ImgMine   -> extract !mine_pixmap
  | ImgBlam   -> extract !blam_pixmap
  | ImgWrong  -> extract !wrong_pixmap
  | ImgOpen   -> (!open_pixmap_arr).(surround)
