(* Code copyright 2003 Alan Post
 *
 * This file is part of mineml.
 *
 * mineml is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * mineml is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with mineml; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *************************************************
 *
 * Images copyright 1993-1999 Marc Baudoin,
 *   available in the 'xdemineur' program under the following license:
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.  The author makes no representations about the suitability of
 * this software for any purpose.  It is provided "as is" without express or
 * implied warranty.
 *)

type game_state_t = GamePlaying | GameWon | GameLost

let normal_pixmap = ref None
let happy_pixmap = ref None
let sad_pixmap = ref None

let init window =
    normal_pixmap := Some (GDraw.pixmap_from_xpm_d ~window ~data: [|
"40 40 6 1";
"  c white";
"# c black";
"X c gray50 m black";
"* c gray70 m black";
". c gray70 m white";
"- c yellow m white";
"                                        ";
"                                       X";
"                                      XX";
"   *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*########.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*###--------###.*.*.*.*.*XXX";
"   *.*.*.*.##--------------##*.*.*.*.XXX";
"   .*.*.*.#------------------#*.*.*.*XXX";
"   *.*.*.#--------------------#*.*.*.XXX";
"   .*.*.#----------------------#*.*.*XXX";
"   *.*.#------------------------#*.*.XXX";
"   .*.*#------------------------#.*.*XXX";
"   *.*#-------##--------##-------#.*.XXX";
"   .*.#------####------####------#*.*XXX";
"   *.*#------####------####------#.*.XXX";
"   .*#--------##--------##--------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*#----------------------------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*#----------------------------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*#----------------------------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*.#------#------------#------#*.*XXX";
"   *.*#-------#----------#-------#.*.XXX";
"   .*.#--------##------##--------#*.*XXX";
"   *.*.#---------######---------#*.*.XXX";
"   .*.*#------------------------#.*.*XXX";
"   *.*.*#----------------------#.*.*.XXX";
"   .*.*.*#--------------------#.*.*.*XXX";
"   *.*.*.*#------------------#.*.*.*.XXX";
"   .*.*.*.*##--------------##.*.*.*.*XXX";
"   *.*.*.*.*.###--------###*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.########*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*XXX";
"   XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
|] ());

    happy_pixmap := Some (GDraw.pixmap_from_xpm_d ~window ~data: [|
"40 40 6 1";
"  c white";
"# c black";
"X c gray50 m black";
"* c gray70 m black";
". c gray70 m white";
"- c yellow m white";
"                                        ";
"                                       X";
"                                      XX";
"   *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*########.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*###--------###.*.*.*.*.*XXX";
"   *.*.*.*.##--------------##*.*.*.*.XXX";
"   .*.*.*.#------------------#*.*.*.*XXX";
"   *.*.*.#--------------------#*.*.*.XXX";
"   .*.*.#----------------------#*.*.*XXX";
"   *.*.#------------------------#*.*.XXX";
"   .*.*#----################----#.*.*XXX";
"   *.*#----##################----#.*.XXX";
"   .*.#---#-################-#---#*.*XXX";
"   *.*#--#--#######--#######--#--#.*.XXX";
"   .*#--#---######----######---#--#.*XXX";
"   *.#-#-----####------####-----#-#*.XXX";
"   .*##-------##--------##-------##.*XXX";
"   *.#----------------------------#*.XXX";
"   .*#----------------------------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*#----------------------------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*.#------#------------#------#*.*XXX";
"   *.*#-------#----------#-------#.*.XXX";
"   .*.#--------##------##--------#*.*XXX";
"   *.*.#---------######---------#*.*.XXX";
"   .*.*#------------------------#.*.*XXX";
"   *.*.*#----------------------#.*.*.XXX";
"   .*.*.*#--------------------#.*.*.*XXX";
"   *.*.*.*#------------------#.*.*.*.XXX";
"   .*.*.*.*##--------------##.*.*.*.*XXX";
"   *.*.*.*.*.###--------###*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.########*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*XXX";
"   XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
|] ());

    sad_pixmap := Some (GDraw.pixmap_from_xpm_d ~window ~data: [|
"40 40 6 1";
"  c white";
"# c black";
"X c gray50 m black";
"* c gray70 m black";
". c gray70 m white";
"- c yellow m white";
"                                        ";
"                                       X";
"                                      XX";
"   *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*########.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*###--------###.*.*.*.*.*XXX";
"   *.*.*.*.##--------------##*.*.*.*.XXX";
"   .*.*.*.#------------------#*.*.*.*XXX";
"   *.*.*.#--------------------#*.*.*.XXX";
"   .*.*.#----------------------#*.*.*XXX";
"   *.*.#------------------------#*.*.XXX";
"   .*.*#------------------------#.*.*XXX";
"   *.*#------#--#------#--#------#.*.XXX";
"   .*.#-------##--------##-------#*.*XXX";
"   *.*#-------##--------##-------#.*.XXX";
"   .*#-------#--#------#--#-------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*#----------------------------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*#----------------------------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*#----------------------------#.*XXX";
"   *.#----------------------------#*.XXX";
"   .*.#----------######----------#*.*XXX";
"   *.*#--------##------##--------#.*.XXX";
"   .*.#-------#----------#-------#*.*XXX";
"   *.*.#-----#------------#-----#*.*.XXX";
"   .*.*#------------------------#.*.*XXX";
"   *.*.*#----------------------#.*.*.XXX";
"   .*.*.*#--------------------#.*.*.*XXX";
"   *.*.*.*#------------------#.*.*.*.XXX";
"   .*.*.*.*##--------------##.*.*.*.*XXX";
"   *.*.*.*.*.###--------###*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.########*.*.*.*.*.*.*XXX";
"   *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.XXX";
"   .*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*XXX";
"   XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
|] ())

let extract o = match o with None -> raise Exit | Some x -> x
let get = function
      GamePlaying -> extract !normal_pixmap
    | GameWon     -> extract !happy_pixmap
    | GameLost    -> extract !sad_pixmap
