(* Copyright 2003 Alan Post
 *
 * This file is part of mineml.
 *
 * mineml is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * mineml is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with mineml; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)


type t = { mutable id: GMain.Timeout.id option;
           mutable start: float;
           left: Numbers.t;
           right: Numbers.t }

let make ~packing ~digits =
    let box = GPack.hbox ~packing () in
    let left = Numbers.make box#pack (digits - 1) in
    ignore (GMisc.image ~packing: box#pack
                ~pixmap:(DigitPixmaps.get_decimal_point ())#pixmap ());
    { id = None;
      start = 0.0;
      left = left;
      right = Numbers.make box#pack 1 }

let start timer =
    Numbers.set timer.left 0;
    Numbers.set timer.right 0;
    timer.start <- Unix.time ();
    timer.id <- Some (GMain.Timeout.add 50
        (fun () -> let delta =
                        (int_of_float (10. *. ((Unix.gettimeofday ())
                                               -. timer.start))) in
                   Numbers.set timer.right (delta mod 10);
                   Numbers.set timer.left (delta / 10);
                   true))

let may f = function None -> () | Some x -> f x

let stop timer =
    may GMain.Timeout.remove timer.id;
    timer.id <- None

let value timer = (Numbers.value timer.left) * 10 + (Numbers.value timer.right)
